@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2004 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,8 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ *
+ *  $Id: ephy-embed-factory.h,v 1.3 2004/09/13 10:24:56 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_FACTORY_H
@@ -25,7 +27,7 @@
 
 G_BEGIN_DECLS
 
-GObject	*ephy_embed_factory_new_object (const char *object_id);
+GObject	*ephy_embed_factory_new_object (GType type);
 
 G_END_DECLS
 
