@@ -15,46 +15,31 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyPromptService.cpp,v 1.10.2.1 2006/04/01 12:00:16 chpe Exp $
+ *  $Id: EphyPromptService.cpp,v 1.13 2006/05/10 18:07:00 chpe Exp $
  */
 
 #include "mozilla-config.h"
 #include "config.h"
 
-#include "EphyPromptService.h"
-#include "AutoJSContextStack.h"
-
-#include <nsCOMPtr.h>
-#include <nsIDOMWindow.h>
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
-
-#if 0
-#include <nsIPrincipal.h>
-#include <nsIScriptSecurityManager.h>
-#include <nsIServiceManager.h>
-#endif
-
-#if 0
-#include "AutoEventQueue.h"
-#endif
-
-#include "EphyUtils.h"
-
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
+#include <nsStringAPI.h>
+
+#include <nsCOMPtr.h>
+#include <nsIDOMWindow.h>
+#include <nsServiceManagerUtils.h>
+
 #include "ephy-embed-shell.h"
 #include "ephy-gui.h"
 #include "ephy-debug.h"
 
-#ifndef HAVE_GECKO_1_8
-typedef nsEmbedString nsDependentString;
-typedef nsEmbedCString nsDependentCString;
-#endif
+#include "AutoJSContextStack.h"
+#include "EphyUtils.h"
+
+#include "EphyPromptService.h"
 
 #define TIMEOUT			1000 /* ms */
 #define TIMEOUT_DATA_KEY	"timeout"
@@ -68,8 +53,6 @@ enum
 	RESPONSE_ABORT_SCRIPT = 42
 };
 
-#define RETVAL(r) (NS_OK)
-
 class Prompter
 {
 public:
@@ -135,8 +118,7 @@ Prompter::Prompter (const char *aStock,
 	mEntries[0] = mEntries[1] = nsnull;
 
 	mDialog = GTK_DIALOG (gtk_dialog_new ());
-	g_object_ref (mDialog);
-	gtk_object_sink (GTK_OBJECT (mDialog));
+	g_object_ref_sink (mDialog);
 
 	char *title = NULL;
 	if (aTitle)
@@ -380,7 +362,7 @@ Prompter::AddEntry (const char *aLabel,
 
 	if (aValue)
 	{
-		nsEmbedCString cValue;
+		nsCString cValue;
 		NS_UTF16ToCString (nsDependentString(aValue),
 				   NS_CSTRING_ENCODING_UTF8, cValue);
 
@@ -405,7 +387,7 @@ Prompter::GetText (PRUint32 aNum,
 	const char *text = gtk_entry_get_text (GTK_ENTRY (mEntries[aNum]));
 	if (!text) return;
 
-	nsEmbedString value;
+	nsString value;
 	NS_CStringToUTF16 (nsDependentCString (text),
 			   NS_CSTRING_ENCODING_UTF8, value);
 
@@ -424,7 +406,7 @@ Prompter::AddSelect (PRUint32 aCount,
 		/* FIXME: use "" instead in this case? */
 		if (!aList[i] || !aList[i][0]) continue;
 
-		nsEmbedCString cData;
+		nsCString cData;
 		NS_UTF16ToCString (nsDependentString(aList[i]), NS_CSTRING_ENCODING_UTF8, cData);
 
 		gtk_combo_box_append_text (GTK_COMBO_BOX (mCombo), cData.get());
@@ -547,18 +529,24 @@ Prompter::Show ()
 PRBool
 Prompter::IsCalledFromScript()
 {
-	/* FIXME: implement me! */
 #if 0
+	nsCOMPtr<nsIXPConnect> xpconnect (do_GetService (nsIXPConnect::GetCID()));
+	NS_ENSURE_TRUE (xpconnect, PR_FALSE);
+
 	nsresult rv;
-	nsCOMPtr<nsIScriptSecurityManager> securityManager =
-			do_GetService(NS_SCRIPTSECURITYMANAGER_CONTRACTID, &rv);
+	nsCOMPtr<nsIXPCNativeCallContext> ncc;
+	rv = xpconnect->GetCurrentNativeCallContext (getter_AddRefs (ncc));
 	NS_ENSURE_SUCCESS (rv, PR_FALSE);
 
-	nsCOMPtr<nsIPrincipal> principal;
-	rv = securityManager->GetSubjectPrincipal (getter_AddRefs (principal));
+	if (!ncc) return PR_FALSE;
 
-	g_print ("rv=%x mPrincipal=%p\n", rv, (void*)principal.get());
-	return NS_SUCCEEDED (rv) && principal.get();
+	JSContext *cx = nsnull;
+	rv = ncc->GetJSContext (&cx);
+	g_print ("GetJSContext rv=%x, cx=%p\n", rv, cx);
+
+	NS_ENSURE_SUCCESS (rv, PR_FALSE);
+
+	return cx != nsnull;
 #endif
 	return PR_FALSE;
 }
@@ -566,14 +554,26 @@ Prompter::IsCalledFromScript()
 void
 Prompter::PerformScriptAbortion()
 {
-	/* FIXME: implement me! */
 #if 0
-	nsresult rv;
-	nsCOMPtr<nsIScriptSecurityManager> securityManager =
-			do_GetService(NS_SCRIPTSECURITYMANAGER_CONTRACTID, &rv);
-	NS_ENSURE_SUCCESS (rv, );
+	/* FIXME: can we only stop the calling script, not all scripts in the context? */
 
-	securityManager->DisableCapability ("javascript.enabled");
+	nsCOMPtr<nsIXPConnect> xpconnect (do_GetService (nsIXPConnect::GetCID()));
+	NS_ENSURE_TRUE (xpconnect, );
+
+	nsresult rv;
+	nsCOMPtr<nsIXPCNativeCallContext> ncc;
+	rv = xpconnect->GetCurrentNativeCallContext (getter_AddRefs (ncc));
+	NS_ENSURE_SUCCESS (rv, );
+	NS_ENSURE_TRUE (ncc, );
+
+	JSContext *cx = nsnull;
+	rv = ncc->GetJSContext (&cx);
+	g_print ("GetJSContext rv=%x, cx=%p\n", rv, cx);
+	NS_ENSURE_SUCCESS (rv, );
+	NS_ENSURE_TRUE (cx, );
+
+	g_print ("Would now disable scripts\n");
+//	MozillaPrivate::SetScriptsEnabled (cx, PR_FALSE, PR_FALSE);
 #endif
 }
 
@@ -662,9 +662,9 @@ EphyPromptService::Alert (nsIDOMWindow *aParent,
 {
 	Prompter prompt (GTK_STOCK_DIALOG_INFO, aParent, aDialogTitle, aText);
 	prompt.AddStockButton (GTK_STOCK_OK, GTK_RESPONSE_ACCEPT);
-	PRInt32 response = prompt.Run ();
+	prompt.Run ();
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* void alertCheck (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -679,10 +679,10 @@ EphyPromptService::AlertCheck (nsIDOMWindow *aParent,
 	prompt.AddStockButton (GTK_STOCK_OK, GTK_RESPONSE_ACCEPT);
 	prompt.AddCheckbox (aCheckMsg, aCheckState);
 
-	PRInt32 response = prompt.Run ();
+	prompt.Run ();
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean confirm (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText); */
@@ -697,9 +697,9 @@ EphyPromptService::Confirm (nsIDOMWindow *aParent,
 	Prompter prompt (GTK_STOCK_DIALOG_QUESTION, aParent, aDialogTitle, aText);
 	prompt.AddStockButton (GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 	prompt.AddStockButton (GTK_STOCK_OK, GTK_RESPONSE_ACCEPT);
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean confirmCheck (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -718,10 +718,10 @@ EphyPromptService::ConfirmCheck (nsIDOMWindow *aParent,
 	prompt.AddStockButton (GTK_STOCK_OK, GTK_RESPONSE_ACCEPT);
 	prompt.AddCheckbox (aCheckMsg, aCheckState);
 
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* PRInt32 confirmEx (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, in unsigned long aButtonFlags, in wstring aButton0Title, in wstring aButton1Title, in wstring aButton2Title, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -744,11 +744,10 @@ EphyPromptService::ConfirmEx (nsIDOMWindow *aParent,
 				    aButton1Title, aButton2Title);
 	prompt.AddCheckbox (aCheckMsg, aCheckState);
 
-	PRInt32 response = prompt.Run (nsnull);
-	*_retval = response;
+	*_retval = prompt.Run (nsnull);
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean prompt (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, inout wstring aValue, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -770,11 +769,11 @@ EphyPromptService::Prompt (nsIDOMWindow *aParent,
 	prompt.AddEntry (nsnull, *aValue, PR_FALSE);
 	prompt.AddCheckbox (aCheckMsg, aCheckState);
 
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 	prompt.GetText (0, aValue);
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean promptUsernameAndPassword (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, inout wstring aUsername, inout wstring aPassword, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -799,12 +798,12 @@ EphyPromptService::PromptUsernameAndPassword (nsIDOMWindow *aParent,
 	prompt.AddEntry (_("_Password:"), *aPassword, PR_TRUE);
 	prompt.AddCheckbox (aCheckMsg, aCheckState);
 
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 	prompt.GetText (0, aUsername);
 	prompt.GetText (1, aPassword);
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean promptPassword (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, inout wstring aPassword, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -828,11 +827,11 @@ EphyPromptService::PromptPassword (nsIDOMWindow *aParent,
 
 	// FIXME: Add a CAPSLOCK indicator?
 
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 	prompt.GetText (0, aPassword);
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean select (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, in PRUint32 aCount, [array, size_is (aCount)] in wstring aSelectList, out long aOutSelection); */
@@ -853,10 +852,10 @@ EphyPromptService::Select (nsIDOMWindow *aParent,
 	prompt.AddStockButton (GTK_STOCK_OK, GTK_RESPONSE_ACCEPT);
 	prompt.AddSelect (aCount, aSelectList, *aOutSelection);
 
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 	prompt.GetSelected (aOutSelection);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 #if HAVE_NSINONBLOCKINGALERTSERVICE_H
