@@ -15,32 +15,33 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyUtils.cpp,v 1.17 2006/01/17 13:58:19 chpe Exp $
+ *  $Id: EphyUtils.cpp,v 1.19 2006/05/14 19:43:10 chpe Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "EphyUtils.h"
+#include <gtkmozembed.h>
+#include <nsCOMPtr.h>
+#include <nsIDOMWindow.h>
+#include <nsIEmbeddingSiteWindow.h>
+#include <nsIFile.h>
+#include <nsIIOService.h>
+#include <nsIPrintSettings.h>
+#include <nsIServiceManager.h>
+#include <nsIURI.h>
+#include <nsIWebBrowserChrome.h>
+#include <nsIWindowWatcher.h>
+#include <nsServiceManagerUtils.h>
+#include <nsStringAPI.h>
+#include <nsXPCOM.h>
+
 #include "ephy-embed-shell.h"
 #include "ephy-embed-single.h"
-#include "print-dialog.h"
 #include "ephy-file-helpers.h"
+#include "print-dialog.h"
 
-#include <nsIIOService.h>
-#include <nsIURI.h>
-#include <nsIFile.h>
-#include <nsIDOMWindow.h>
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
-#include <nsIWindowWatcher.h>
-#include <nsIEmbeddingSiteWindow.h>
-#include <nsIWebBrowserChrome.h>
-#include <gtkmozembed.h>
-#include <nsIPrintSettings.h>
+#include "EphyUtils.h"
 
 nsresult
 EphyUtils::GetIOService (nsIIOService **ioService)
@@ -63,7 +64,7 @@ EphyUtils::NewURI (nsIURI **result,
 		   const char *charset,
 		   nsIURI *baseURI)
 {
-	nsEmbedCString cSpec;
+	nsCString cSpec;
 	NS_UTF16ToCString (spec, NS_CSTRING_ENCODING_UTF8, cSpec);
 
 	return NewURI (result, cSpec, charset, baseURI);
@@ -147,7 +148,7 @@ EphyUtils::CollatePrintSettings (EmbedPrintInfo *info,
 
 	/* FIXME: for CUPS printers, print directly instead of to a tmp file? */
 	const static PRUnichar pName[] = { 'P', 'o', 's', 't', 'S', 'c', 'r', 'i', 'p', 't', '/', 'd', 'e', 'f', 'a', 'u', 'l', 't', '\0' };
-	options->SetPrinterName(nsEmbedString(pName).get());
+	options->SetPrinterName(nsString(pName).get());
 
 	const static int frame_types[] = {
 		nsIPrintSettings::kFramesAsIs,
@@ -216,29 +217,29 @@ EphyUtils::CollatePrintSettings (EmbedPrintInfo *info,
 	}
 
 
-	nsEmbedString tmp;
+	nsString tmp;
 
-	NS_CStringToUTF16 (nsEmbedCString(info->header_left_string),
+	NS_CStringToUTF16 (nsCString(info->header_left_string),
 			   NS_CSTRING_ENCODING_UTF8, tmp);
 	options->SetHeaderStrLeft (tmp.get());
 
-	NS_CStringToUTF16 (nsEmbedCString(info->header_center_string),
+	NS_CStringToUTF16 (nsCString(info->header_center_string),
 			   NS_CSTRING_ENCODING_UTF8, tmp);
 	options->SetHeaderStrCenter (tmp.get());
 
-	NS_CStringToUTF16 (nsEmbedCString(info->header_right_string),
+	NS_CStringToUTF16 (nsCString(info->header_right_string),
 			   NS_CSTRING_ENCODING_UTF8, tmp);
 	options->SetHeaderStrRight (tmp.get());
 
-	NS_CStringToUTF16 (nsEmbedCString(info->footer_left_string),
+	NS_CStringToUTF16 (nsCString(info->footer_left_string),
 			   NS_CSTRING_ENCODING_UTF8, tmp);
 	options->SetFooterStrLeft (tmp.get());
 
-	NS_CStringToUTF16 (nsEmbedCString(info->footer_center_string),
+	NS_CStringToUTF16 (nsCString(info->footer_center_string),
 			   NS_CSTRING_ENCODING_UTF8, tmp);
 	options->SetFooterStrCenter(tmp.get());
 
-	NS_CStringToUTF16 (nsEmbedCString(info->footer_right_string),
+	NS_CStringToUTF16 (nsCString(info->footer_right_string),
 			   NS_CSTRING_ENCODING_UTF8, tmp);
 	options->SetFooterStrRight(tmp.get());
 
@@ -260,7 +261,7 @@ EphyUtils::CollatePrintSettings (EmbedPrintInfo *info,
 		
 		if (info->tempfile == NULL) return NS_ERROR_FAILURE;
 		
-		NS_CStringToUTF16 (nsEmbedCString(info->tempfile),
+		NS_CStringToUTF16 (nsCString(info->tempfile),
 				   NS_CSTRING_ENCODING_UTF8, tmp);
 		options->SetPrintToFile (PR_TRUE);
 		options->SetToFileName (tmp.get());
@@ -321,7 +322,7 @@ EphyUtils::CollatePrintSettings (EmbedPrintInfo *info,
 	}
 #endif /* !HAVE_GECKO_1_9 */
 
-	NS_CStringToUTF16 (nsEmbedCString(paper),
+	NS_CStringToUTF16 (nsCString(paper),
 			   NS_CSTRING_ENCODING_UTF8, tmp);
 	options->SetPaperName (tmp.get());
 	g_free (string);
@@ -346,16 +347,3 @@ EphyUtils::CollatePrintSettings (EmbedPrintInfo *info,
 
 	return NS_OK;
 }
-
-PRBool
-EphyUtils::StringEquals (nsAString &s1, nsAString &s2)
-{
-	if (s1.Length() != s2.Length())
-	{
-		return FALSE;
-	}
-
-	return (memcmp (s1.BeginReading(),
-		        s2.BeginReading(),
-		        s2.Length() * sizeof (PRUnichar)) == 0);
-}
