@@ -15,22 +15,28 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyUtils.h,v 1.10 2006/01/17 13:58:20 chpe Exp $
+ *  $Id: EphyUtils.h,v 1.12 2006/05/14 19:43:10 chpe Exp $
  */
 
 #ifndef EPHY_UTILS_H
 #define EPHY_UTILS_H
 
-#include <nsError.h>
+// cannot include EphyUtils with internal strings!
+#ifdef MOZILLA_INTERNAL_API
+#error Cannot use EphyUtils with MOZILLA_INTERNAL_API
+#endif
+
+#include <nscore.h>
+
 #include <gtk/gtkwidget.h>
 
-class nsAString;
 class nsACString;
+class nsAString;
 class nsIDOMWindow;
+class nsIFile;
 class nsIIOService;
 class nsIPrintSettings;
 class nsIURI;
-class nsIFile;
 struct _EmbedPrintInfo;
 
 namespace EphyUtils
@@ -57,8 +63,6 @@ namespace EphyUtils
 	nsresult        CollatePrintSettings	(_EmbedPrintInfo *info,
 						 nsIPrintSettings *settings,
 						 gboolean preview);
-	PRBool          StringEquals            (nsAString &s1, 
-						 nsAString &s2);
 }
 
 #endif
