@@ -15,12 +15,9 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozillaPrivate.h,v 1.9 2005/03/10 15:50:36 chpe Exp $
+ *  $Id: MozillaPrivate.h,v 1.11 2006/05/10 18:07:00 chpe Exp $
  */
 
-#include <glib.h>
-
 namespace MozillaPrivate
 {
-	GList   *GetPrinterList ();
 }
