@@ -17,35 +17,36 @@
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
-*  $Id: mozilla-notifiers.cpp,v 1.67 2006/04/02 20:04:17 chpe Exp $
+*  $Id: mozilla-notifiers.cpp,v 1.68 2006/05/10 18:07:00 chpe Exp $
 */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "mozilla-notifiers.h"
-
-#include "eel-gconf-extensions.h"
-#include "ephy-prefs.h"
-#include "ephy-embed-prefs.h"
-#include "ephy-langs.h"
-#include "ephy-node.h"
-#include "ephy-encodings.h"
-#include "ephy-embed-shell.h"
-#include "ephy-debug.h"
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include <glib/gi18n.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtksettings.h>
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
 
 #include <nsCOMPtr.h>
-#include <nsIServiceManager.h>
 #include <nsIPrefService.h>
+#include <nsIServiceManager.h>
 #include <nsMemory.h>
+#include <nsServiceManagerUtils.h>
+
+#include "eel-gconf-extensions.h"
+#include "ephy-debug.h"
+#include "ephy-embed-prefs.h"
+#include "ephy-embed-shell.h"
+#include "ephy-encodings.h"
+#include "ephy-langs.h"
+#include "ephy-node.h"
+#include "ephy-prefs.h"
+
+#include "mozilla-notifiers.h"
 
 /* define to migrate epiphany 1.0 font preferences */
 #define MIGRATE_PIXEL_SIZE
@@ -645,7 +646,7 @@ mozilla_get_dpi ()
 	if (g_object_class_find_property (G_OBJECT_GET_CLASS (G_OBJECT (settings)),
 					  "gtk-xft-dpi"))
 	{
-		g_object_get (G_OBJECT (settings), "gtk-xft-dpi", &dpi, NULL);
+		g_object_get (G_OBJECT (settings), "gtk-xft-dpi", &dpi, (char *) NULL);
 		if (dpi) return INT_ROUND (dpi / PANGO_SCALE);
 	}
 
