@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node.c,v 1.43 2006/02/07 14:44:47 chpe Exp $
+ *  $Id: ephy-node.c,v 1.44 2006/03/23 21:23:58 chpe Exp $
  */
 
 #include "config.h"
@@ -689,7 +689,7 @@ write_parent (guint id,
 	if (data->ret < 0) return;
 
 	data->ret = xmlTextWriterWriteFormatAttribute
-			(writer, (const xmlChar *)"id", "%ld", node_info->node->id);
+			(writer, (const xmlChar *)"id", "%d", node_info->node->id);
 	if (data->ret < 0) return;
 
 	data->ret = xmlTextWriterEndElement (writer); /* parent */
@@ -713,7 +713,7 @@ ephy_node_write_to_xml(EphyNode *node,
 	if (ret < 0) goto out;
 
 	/* write node id */
-	ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar *)"id", "%ld", node->id);
+	ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar *)"id", "%d", node->id);
 	if (ret < 0) goto out;
 
 	/* write node properties */
