@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.191 2006/03/02 21:23:34 jframeau Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.194 2006/04/20 17:45:34 chpe Exp $
  */
 
 #include "config.h"
@@ -69,6 +69,7 @@
 #include "eel-gconf-extensions.h"
 #include "ephy-debug.h"
 #include "egg-toolbars-model.h"
+#include "ephy-prefs.h"
 
 static const GtkTargetEntry topic_drag_dest_types [] =
 {
@@ -93,9 +94,10 @@ static const struct
 	const char *extension;
 }
 export_formats [] = 
+/* Don't add or reoder those entries without updating export_dialog_response_cb too! */
 {
-	{ N_("Mozilla (HTML)"), "html" },
-	{ N_("Epiphany (RDF)"), "rdf" }
+	{ N_("Epiphany (RDF)"), "rdf" },
+	{ N_("Mozilla (HTML)"), "html" }
 };
 
 static void ephy_bookmarks_editor_class_init (EphyBookmarksEditorClass *klass);
@@ -762,7 +764,7 @@ import_dialog_response_cb (GtkDialog *dialog,
 			EphyFileChooser *dialog;
 			GtkFileFilter *filter;
 
-			dialog = ephy_file_chooser_new (_("Import bookmarks from file"),
+			dialog = ephy_file_chooser_new (_("Import Bookmarks from File"),
 							GTK_WIDGET (editor),
 							GTK_FILE_CHOOSER_ACTION_OPEN,
 							NULL, EPHY_FILE_FILTER_NONE);
@@ -1751,6 +1753,7 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 	EphyNode *node;
 	GtkUIManager *ui_merge;
 	GtkActionGroup *action_group;
+	GtkAction *action;
 	int col_id, url_col_id, title_col_id, details_value;
 
 	ephy_gui_ensure_window_group (GTK_WINDOW (editor));
@@ -1934,6 +1937,11 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 			       130);
 
 	set_columns_visibility (editor, details_value);
+
+	/* Lockdown settings */
+	action = gtk_action_group_get_action (action_group, "Export");
+	gtk_action_set_sensitive (action,
+				  eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_SAVE_TO_DISK) == FALSE);
 }
 
 void
