@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.191 2006/03/12 18:21:14 chpe Exp $
+ *  $Id: window-commands.c,v 1.193 2006/04/24 07:45:19 chpe Exp $
  */
 
 #include "config.h"
@@ -755,8 +755,9 @@ window_cmd_help_about (GtkAction *action,
 	shell = ephy_embed_shell_get_default ();
 	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (shell));
 
-	comments = g_strdup_printf (_("Using “%s” backend"),
-				    ephy_embed_single_get_backend_name (single));
+	comments = g_strdup_printf (_("Lets you view web pages and find information on the internet.\n"
+				      "Powered by Gecko %s"),
+				      ephy_embed_single_get_backend_name (single) + strlen ("gecko-"));
 	licence = g_strjoin ("\n\n",
 			     _(licence_part[0]),
 			     _(licence_part[1]),
@@ -833,61 +834,32 @@ void
 window_cmd_tabs_move_left  (GtkAction *action,
 			    EphyWindow *window)
 {
-	GtkWidget *notebook;
+	GtkWidget *child;
+	GtkNotebook *notebook;
 	int page;
 
-	notebook = ephy_window_get_notebook (window);
-	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+	notebook = GTK_NOTEBOOK (ephy_window_get_notebook (window));
+	page = gtk_notebook_get_current_page (notebook);
+	if (page < 1) return;
 
-	if (page > 0)
-	{
-		GtkWidget *child;
-
-		child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), page);
-		ephy_notebook_move_tab (EPHY_NOTEBOOK (notebook), NULL,
-					EPHY_TAB (child), page - 1);
-	}
+	child = gtk_notebook_get_nth_page (notebook, page);
+	gtk_notebook_reorder_child (notebook, child, page - 1);
 }
 
 void window_cmd_tabs_move_right (GtkAction *action,
 				 EphyWindow *window)
 {
-	GtkWidget *notebook;
-	int page;
-	int last_page;
+	GtkWidget *child;
+	GtkNotebook *notebook;
+	int page, n_pages;
 
-	notebook = ephy_window_get_notebook (window);
-	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
-	last_page = gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook)) - 1;
+	notebook = GTK_NOTEBOOK (ephy_window_get_notebook (window));
+	page = gtk_notebook_get_current_page (notebook);
+	n_pages = gtk_notebook_get_n_pages (notebook) - 1;
+	if (page > n_pages - 1) return;
 
-	if (page != last_page)
-	{
-		GtkWidget *child;
-
-		child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), page);
-		ephy_notebook_move_tab (EPHY_NOTEBOOK (notebook), NULL,
-					EPHY_TAB (child), page + 1);
-	}
-}
-
-void
-window_cmd_tabs_detach  (GtkAction *action,
-			 EphyWindow *window)
-{
-	EphyTab *tab;
-	GtkWidget *nb;
-	EphyWindow *new_win;
-
-	nb = ephy_window_get_notebook (window);
-	if (gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb)) <= 1) return;
-
-	tab = ephy_window_get_active_tab (window);
-
-	new_win = ephy_window_new ();
-	ephy_notebook_move_tab (EPHY_NOTEBOOK (ephy_window_get_notebook (window)),
-				EPHY_NOTEBOOK (ephy_window_get_notebook (new_win)),
-				tab, 0);
-	gtk_widget_show (GTK_WIDGET (new_win));
+	child = gtk_notebook_get_nth_page (notebook, page);
+	gtk_notebook_reorder_child (notebook, child, page + 1);
 }
 
 void
